@@ -391,7 +391,7 @@ int doget(WINDOW *win, sock_t *m)
   
   sv = findsock("server");
   if (sv)
-    sendpack(sv->fd, F_UP, NULL);
+    sendpack(sv->fd, NAP_UP, NULL);
   
   /* send the file size */
   ssock(m->fd, "%lu", (long)task->size);
@@ -540,7 +540,7 @@ int dosend(WINDOW *win, sock_t *m)
   m->func = gfile;
   sv = findsock("server");
   if (sv)
-    sendpack(sv->fd, F_DOWN, NULL);
+    sendpack(sv->fd, NAP_DOWN, NULL);
   
   /* send offset */
   ssock(m->fd, "%lu", (long)0);
@@ -663,7 +663,7 @@ int initsend(WINDOW *win, sock_t *m)
     drw(win);
     sk = findsock("server");
     if (sk)
-      sendpack(sk->fd, F_MISCONFIGURE, "%s", task->nick);
+      sendpack(sk->fd, NAP_MISCONFIGURE, "%s", task->nick);
     fclose(f);
     task->state=FAILED;
     task->d_time = time(0);
@@ -777,7 +777,7 @@ int initget(WINDOW *win, sock_t *m)
     drw(win);
     sk = findsock("server");
     if (sk)
-      sendpack(sk->fd, F_MISCONFIGURE, "%s", task->nick);
+      sendpack(sk->fd, NAP_MISCONFIGURE, "%s", task->nick);
     free(task->check);
     task->state = FAILED;
     task->d_time = time(0);
@@ -814,7 +814,7 @@ int gsize(WINDOW *win, sock_t *m)
       drw(win);
       sk = findsock("server");
       if (sk)
-        sendpack(sk->fd, F_MISCONFIGURE, "%s", task->nick);
+        sendpack(sk->fd, NAP_MISCONFIGURE, "%s", task->nick);
       free(task->check);
       task->state = FAILED;
       task->d_time = time(0);
