@@ -423,9 +423,9 @@ I_IRC_FUNC(h353)
         adduser(cur, tok[i]+2, 0, 0);
         usr = finduser(cur, tok[i]+2);
         if (*(tok[i]+1) == '@')
-          usr->flag |= F_OP;
+          usr->flag |= NAP_OP;
         else
-          usr->flag |= F_VOICE;
+          usr->flag |= NAP_VOICE;
       }
       else
       {
@@ -448,9 +448,9 @@ I_IRC_FUNC(h353)
         adduser(cur, tok[i]+1, 0, 0);
         usr = finduser(cur, tok[i]+1);
         if (*tok[i] == '@')
-          usr->flag |= F_OP;
+          usr->flag |= NAP_OP;
         else
-          usr->flag |= F_VOICE;
+          usr->flag |= NAP_VOICE;
       }
       else
       {
@@ -815,13 +815,13 @@ I_IRC_FUNC(hmode)
       {
         cur = finduser(c, tok[j]);
         if (cur)
-          cur->flag |= F_OP;
+          cur->flag |= NAP_OP;
       }
       else if (m == '-')
       {
         cur = finduser(c, tok[j]);
         if (cur)
-          cur->flag &= ~F_OP;
+          cur->flag &= ~NAP_OP;
       }
       j++;
     }
@@ -831,13 +831,13 @@ I_IRC_FUNC(hmode)
       {
         cur = finduser(c, tok[j]);
         if (cur)
-          cur->flag |= F_VOICE;
+          cur->flag |= NAP_VOICE;
       }
       else if (m == '-')
       {
         cur = finduser(c, tok[j]);
         if (cur)
-          cur->flag &= ~F_VOICE;
+          cur->flag &= ~NAP_VOICE;
       }
       j++;
     }
@@ -846,55 +846,55 @@ I_IRC_FUNC(hmode)
     else if (tok[3][i] == 'i')
     {
       if (m == '+')
-        c->flag |= F_I;
+        c->flag |= NAP_I;
       else if (m == '-')
-        c->flag &= ~F_I;
+        c->flag &= ~NAP_I;
     }
     else if (tok[3][i] == 's')
     {
       if (m == '+')
-        c->flag |= F_S;
+        c->flag |= NAP_S;
       else if (m == '-')
-        c->flag &= ~F_S;
+        c->flag &= ~NAP_S;
     }
     else if (tok[3][i] == 'p')
     {
       if (m == '+')
-        c->flag |= F_P;
+        c->flag |= NAP_P;
       else if (m == '-')
-        c->flag &= ~F_P;
+        c->flag &= ~NAP_P;
     }
     else if (tok[3][i] == 't')
     {
       if (m == '+')
-        c->flag |= F_T;
+        c->flag |= NAP_T;
       else if (m == '-')
-        c->flag &= ~F_T;
+        c->flag &= ~NAP_T;
     }
     else if (tok[3][i] == 'm')
     {
       if (m == '+')
-        c->flag |= F_M;
+        c->flag |= NAP_M;
       else if (m == '-')
-        c->flag &= ~F_M;
+        c->flag &= ~NAP_M;
     }
     else if (tok[3][i] == 'n')
     {
       if (m == '+')
-        c->flag |= F_N;
+        c->flag |= NAP_N;
       else if (m == '-')
-        c->flag &= ~F_N;
+        c->flag &= ~NAP_N;
     }
     else if (tok[3][i] == 'k')
     {
       if (m == '+')
       {
-        c->flag |= F_K;
+        c->flag |= NAP_K;
         c->key = strdup(tok[j]);
       }
       else if (m == '-')
       {
-        c->flag &= ~F_K;
+        c->flag &= ~NAP_K;
         free(c->key);
         c->key = NULL;
       }
@@ -904,13 +904,13 @@ I_IRC_FUNC(hmode)
     {
       if (m == '+')
       {
-        c->flag |= F_L;
+        c->flag |= NAP_L;
         c->l = atoi(tok[j]);
         j++;
       }
       else if (m == '-')
       {
-        c->flag &= ~F_L;
+        c->flag &= ~NAP_L;
         c->l = 0;
       }
     }
@@ -944,55 +944,55 @@ I_IRC_FUNC(h324)
     else if (tok[4][i] == 'i')
     {
       if (m == '+')
-        c->flag |= F_I;
+        c->flag |= NAP_I;
       else if (m == '-')
-        c->flag &= ~F_I;
+        c->flag &= ~NAP_I;
     }
     else if (tok[4][i] == 's')
     {
       if (m == '+')
-        c->flag |= F_S;
+        c->flag |= NAP_S;
       else if (m == '-')
-        c->flag &= ~F_S;
+        c->flag &= ~NAP_S;
     }
     else if (tok[4][i] == 'p')
     {
       if (m == '+')
-        c->flag |= F_P;
+        c->flag |= NAP_P;
       else if (m == '-')
-        c->flag &= ~F_P;
+        c->flag &= ~NAP_P;
     }
     else if (tok[4][i] == 't')
     {
       if (m == '+')
-        c->flag |= F_T;
+        c->flag |= NAP_T;
       else if (m == '-')
-        c->flag &= ~F_T;
+        c->flag &= ~NAP_T;
     }
     else if (tok[4][i] == 'm')
     {
       if (m == '+')
-        c->flag |= F_M;
+        c->flag |= NAP_M;
       else if (m == '-')
-        c->flag &= ~F_M;
+        c->flag &= ~NAP_M;
     }
     else if (tok[4][i] == 'n')
     {
       if (m == '+')
-        c->flag |= F_N;
+        c->flag |= NAP_N;
       else if (m == '-')
-        c->flag &= ~F_N;
+        c->flag &= ~NAP_N;
     }
     else if (tok[4][i] == 'k')
     {
       if (m == '+')
       {
-        c->flag |= F_K;
+        c->flag |= NAP_K;
         c->key = strdup(tok[j]);
       }
       else if (m == '-')
       {
-        c->flag &= ~F_K;
+        c->flag &= ~NAP_K;
         free(c->key);
         c->key = NULL;
       }
@@ -1002,13 +1002,13 @@ I_IRC_FUNC(h324)
     {
       if (m == '+')
       {
-        c->flag |= F_L;
+        c->flag |= NAP_L;
         c->l = atoi(tok[j]);
         j++;
       }
       else if (m == '-')
       {
-        c->flag &= ~F_L;
+        c->flag &= ~NAP_L;
         c->l = 0;
       }
     }
@@ -1512,7 +1512,7 @@ O_IRC_FUNC(ipart)
     sk = findsock("server");
     if (sk)
     {
-      sendpack(sk->fd, F_PART, "%s", pt->nm);
+      sendpack(sk->fd, NAP_PART, "%s", pt->nm);
       pt->p |= 1;
     }
     return;
@@ -1693,7 +1693,7 @@ O_IRC_FUNC(iopsay)
       c = 0;
     }
     
-    if (usr->flag & F_OP)
+    if (usr->flag & NAP_OP)
     {
       strcat(buf, usr->nm);
       strcat(buf, ",");
