@@ -335,35 +335,35 @@ void dstatus()
       if (strlen(curchan->nm) > COLS/4)
         t[COLS/4] = 0;
       cur = finduser(curchan, mnick);
-      if (cur->flag & F_OP)
+      if (cur->flag & NAP_OP)
         mvwprintw(sep, 0, 0, " [@%s] [%s +", mnick, t);
-      else if (cur->flag & F_VOICE)
+      else if (cur->flag & NAP_VOICE)
         mvwprintw(sep, 0, 0, " [+%s] [%s +", mnick, t);
       else
         mvwprintw(sep, 0, 0, " [%s] [%s +", mnick, t);
-      if (curchan->flag & F_I)
+      if (curchan->flag & NAP_I)
         waddch(sep, 'i');
-      if (curchan->flag & F_S)
+      if (curchan->flag & NAP_S)
         waddch(sep, 's');
-      if (curchan->flag & F_P)
+      if (curchan->flag & NAP_P)
         waddch(sep, 'p');
-      if (curchan->flag & F_T)
+      if (curchan->flag & NAP_T)
         waddch(sep, 't');
-      if (curchan->flag & F_M)
+      if (curchan->flag & NAP_M)
         waddch(sep, 'm');
-      if (curchan->flag & F_N)
+      if (curchan->flag & NAP_N)
         waddch(sep, 'n');
-      if (curchan->flag & F_K)
+      if (curchan->flag & NAP_K)
         waddch(sep, 'k');
-      if (curchan->flag & F_L)
+      if (curchan->flag & NAP_L)
         waddch(sep, 'l');
-      if (curchan->flag & F_K || curchan->flag & F_L)
+      if (curchan->flag & NAP_K || curchan->flag & NAP_L)
         waddch(sep, ' ');
-      if (curchan->flag & F_K)
+      if (curchan->flag & NAP_K)
         wprintw(sep, "%s", curchan->key);
-      if (curchan->flag & F_K && curchan->flag & F_L)
+      if (curchan->flag & NAP_K && curchan->flag & NAP_L)
         waddch(sep, ' ');
-      if (curchan->flag & F_L)
+      if (curchan->flag & NAP_L)
         wprintw(sep, "%i", (unsigned int)curchan->l);
       waddch(sep, ']');
       free(t);
@@ -375,9 +375,9 @@ void dstatus()
       if (strlen(curchan->nm) > COLS/4)
         t[COLS/4] = 0;
       cur = finduser(curchan, mnick);
-      if (cur->flag & F_OP)
+      if (cur->flag & NAP_OP)
         mvwprintw(sep, 0, 0, " [@%s] [%s]", mnick, t);
-      else if (cur->flag & F_VOICE)
+      else if (cur->flag & NAP_VOICE)
         mvwprintw(sep, 0, 0, " [+%s] [%s]", mnick, t);
       else
         mvwprintw(sep, 0, 0, " [%s] [%s]", mnick, t);
@@ -1007,7 +1007,7 @@ int input(WINDOW *win, sock_t *m)
       drw(win);
     } else if (curchan->q == 1) {
       msg = fixquotes(strdup(command));
-      sendpack(s, F_TELL, "%s %s", curchan->nm, msg);
+      sendpack(s, NAP_TELL, "%s %s", curchan->nm, msg);
       recent = curchan;
       wp(win, "%s* --> (%s%s%s)%s %s\n", GREEN, WHITE, curchan->nm, GREEN, WHITE, msg);
       drw(win);
@@ -1021,7 +1021,7 @@ int input(WINDOW *win, sock_t *m)
       recent = NULL;
     } else {
       msg = fixquotes(strdup(command));
-      if (sendpack(s, F_SAY, "%s %s", curchan->nm, msg) == -1) {
+      if (sendpack(s, NAP_SAY, "%s %s", curchan->nm, msg) == -1) {
 	delsock(s);  /* s is the server, or -1 if no server */
       }
       free(msg);
